==> jc-1.4.0.tar.gz: soot/util/Numberer.h <==
// public class soot.util.Numberer

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f5f751433138bc27 soot_util_Numberer

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_Numberer_H_
#define _JC_soot_util_Numberer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_util_Numberable$object;
struct _jc_soot_util_Numberer__24NumbererIterator$object;

// Typedefs
typedef struct _jc_soot_util_Numberer$sub_refs	_jc_soot_util_Numberer$sub_refs;
typedef struct _jc_soot_util_Numberer$sub_nonrefs	_jc_soot_util_Numberer$sub_nonrefs;
typedef struct _jc_soot_util_Numberer$refs	_jc_soot_util_Numberer$refs;
typedef struct _jc_soot_util_Numberer$nonrefs	_jc_soot_util_Numberer$nonrefs;
typedef struct _jc_soot_util_Numberer$object	_jc_soot_util_Numberer$object;

typedef const struct _jc_soot_util_Numberer$vmethods	_jc_soot_util_Numberer$vmethods;
typedef const struct _jc_soot_util_Numberer$vtable	_jc_soot_util_Numberer$vtable;
typedef const struct _jc_soot_util_Numberer$vtype	_jc_soot_util_Numberer$vtype;

// Constructors
extern void _jc_soot_util_Numberer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_util_Numberer$object *);

// Virtual methods
extern void _jc_soot_util_Numberer$method$add$5470e142c10db8b0(_jc_env *, struct _jc_soot_util_Numberer$object *, struct _jc_object *);
extern struct _jc_object *_jc_soot_util_Numberer$method$get$04de956ab1bc7361(_jc_env *, struct _jc_soot_util_Numberer$object *, jint);
extern struct _jc_soot_util_Numberer__24NumbererIterator$object *_jc_soot_util_Numberer$method$iterator$9e517097658c0b6e(_jc_env *, struct _jc_soot_util_Numberer$object *);
extern jint _jc_soot_util_Numberer$method$size$345df5220fc60ade(_jc_env *, struct _jc_soot_util_Numberer$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_util_Numberer$method_info$add$5470e142c10db8b0;
extern _jc_method _jc_soot_util_Numberer$method_info$get$04de956ab1bc7361;
extern _jc_method _jc_soot_util_Numberer$method_info$iterator$9e517097658c0b6e;
extern _jc_method _jc_soot_util_Numberer$method_info$size$345df5220fc60ade;

// Virtual methods structure
struct _jc_soot_util_Numberer$vmethods {
	void	(*add$5470e142c10db8b0)(_jc_env *, struct _jc_soot_util_Numberer$object *, struct _jc_object *);
	struct _jc_object	*(*get$04de956ab1bc7361)(_jc_env *, struct _jc_soot_util_Numberer$object *, jint);
	struct _jc_soot_util_Numberer__24NumbererIterator$object	*(*iterator$9e517097658c0b6e)(_jc_env *, struct _jc_soot_util_Numberer$object *);
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_soot_util_Numberer$object *);
};

// Vtable
struct _jc_soot_util_Numberer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_Numberer$vmethods	soot_util_Numberer;
};

// Vtype
struct _jc_soot_util_Numberer$vtype {
	_jc_type			type;
	_jc_soot_util_Numberer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_Numberer$sub_refs {
	_jc_object_array	*numberToObj;
};

// Reference instance fields (object)
struct _jc_soot_util_Numberer$refs {
    _jc_soot_util_Numberer$sub_refs	soot_util_Numberer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_Numberer$sub_nonrefs {
	jint	lastNumber;
};

// Non-reference instance fields (object)
struct _jc_soot_util_Numberer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_Numberer$sub_nonrefs	soot_util_Numberer;
};

// Object instance structure
struct _jc_soot_util_Numberer$object {
	_jc_soot_util_Numberer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_Numberer$vtype	*vtype;
	_jc_soot_util_Numberer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_Numberer$vtype _jc_soot_util_Numberer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_Numberer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_Numberer$class_object;

#endif	/* _JC_soot_util_Numberer_H_ */

==> jc-1.4.6.tar.gz: soot/util/Numberer.h <==
// public class soot.util.Numberer

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f5f751433138bc27 soot_util_Numberer

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_Numberer_H_
#define _JC_soot_util_Numberer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_util_Numberable$object;
struct _jc_soot_util_Numberer__24NumbererIterator$object;

// Typedefs
typedef struct _jc_soot_util_Numberer$sub_refs	_jc_soot_util_Numberer$sub_refs;
typedef struct _jc_soot_util_Numberer$sub_nonrefs	_jc_soot_util_Numberer$sub_nonrefs;
typedef struct _jc_soot_util_Numberer$refs	_jc_soot_util_Numberer$refs;
typedef struct _jc_soot_util_Numberer$nonrefs	_jc_soot_util_Numberer$nonrefs;
typedef struct _jc_soot_util_Numberer$object	_jc_soot_util_Numberer$object;

typedef const struct _jc_soot_util_Numberer$vmethods	_jc_soot_util_Numberer$vmethods;
typedef const struct _jc_soot_util_Numberer$vtable	_jc_soot_util_Numberer$vtable;
typedef const struct _jc_soot_util_Numberer$vtype	_jc_soot_util_Numberer$vtype;

// Constructors
extern void _jc_soot_util_Numberer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_util_Numberer$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_util_Numberer$method$add$5470e142c10db8b0(_jc_env *, struct _jc_soot_util_Numberer$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_util_Numberer$method$get$04de956ab1bc7361(_jc_env *, struct _jc_soot_util_Numberer$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_soot_util_Numberer__24NumbererIterator$object *_jc_soot_util_Numberer$method$iterator$9e517097658c0b6e(_jc_env *, struct _jc_soot_util_Numberer$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_util_Numberer$method$size$345df5220fc60ade(_jc_env *, struct _jc_soot_util_Numberer$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_util_Numberer$method_info$add$5470e142c10db8b0;
extern _jc_method _jc_soot_util_Numberer$method_info$get$04de956ab1bc7361;
extern _jc_method _jc_soot_util_Numberer$method_info$iterator$9e517097658c0b6e;
extern _jc_method _jc_soot_util_Numberer$method_info$size$345df5220fc60ade;

// Virtual methods structure
struct _jc_soot_util_Numberer$vmethods {
	void	(*add$5470e142c10db8b0)(_jc_env *, struct _jc_soot_util_Numberer$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*get$04de956ab1bc7361)(_jc_env *, struct _jc_soot_util_Numberer$object *, jint) _JC_JCNI_ATTR;
	struct _jc_soot_util_Numberer__24NumbererIterator$object	*(*iterator$9e517097658c0b6e)(_jc_env *, struct _jc_soot_util_Numberer$object *) _JC_JCNI_ATTR;
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_soot_util_Numberer$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_util_Numberer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_Numberer$vmethods	soot_util_Numberer;
};

// Vtype
struct _jc_soot_util_Numberer$vtype {
	_jc_type			type;
	_jc_soot_util_Numberer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_Numberer$sub_refs {
	_jc_object_array	*numberToObj;
};

// Reference instance fields (object)
struct _jc_soot_util_Numberer$refs {
    _jc_soot_util_Numberer$sub_refs	soot_util_Numberer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_Numberer$sub_nonrefs {
	jint	lastNumber;
};

// Non-reference instance fields (object)
struct _jc_soot_util_Numberer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_Numberer$sub_nonrefs	soot_util_Numberer;
};

// Object instance structure
struct _jc_soot_util_Numberer$object {
	_jc_soot_util_Numberer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_Numberer$vtype	*vtype;
	_jc_soot_util_Numberer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_Numberer$vtype _jc_soot_util_Numberer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_Numberer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_Numberer$class_object;

#endif	/* _JC_soot_util_Numberer_H_ */
